@@ -292,6 +292,7 @@ class KubeCluster(Cluster):
                 f"{self.name}-scheduler",
                 self.namespace,
                 port_name="http-dashboard",
+                port_forward_cluster_ip=self.port_forward_cluster_ip,
             )
             self.forwarded_dashboard_port = dashboard_address.split(":")[-1]
 
@@ -322,6 +323,7 @@ class KubeCluster(Cluster):
                 service_name,
                 self.namespace,
                 port_name="http-dashboard",
+                port_forward_cluster_ip=self.port_forward_cluster_ip,
             )
             self.forwarded_dashboard_port = dashboard_address.split(":")[-1]
 
@@ -340,7 +342,11 @@ class KubeCluster(Cluster):
                 return None
 
     async def _get_scheduler_address(self):
-        address = await get_scheduler_address(f"{self.name}-scheduler", self.namespace)
+        address = await get_scheduler_address(
+            f"{self.name}-scheduler",
+            self.namespace,
+            port_forward_cluster_ip=self.port_forward_cluster_ip,
+        )
         return address
 
     async def _wait_for_controller(self):
@@ -358,7 +364,14 @@ class KubeCluster(Cluster):
                 timeout_seconds=self._resource_timeout,
             ):
                 cluster = event["object"]
-                if "status" in cluster and "phase" in cluster["status"]:
+
+                # Wait until the phase is actually Running, ignoring
+                # other non-ready phases such as Created.
+                if (
+                    "status" in cluster
+                    and "phase" in cluster["status"]
+                    and cluster["status"]["phase"] == "Running"
+                ):
                     return
                 await asyncio.sleep(0.1)
         raise TimeoutError(
@@ -476,13 +489,13 @@ class KubeCluster(Cluster):
             spec = custom_spec
         else:
             spec = make_worker_spec(
-                cluster_name=self.name,
                 env=env or self.env,
                 resources=resources or self.resources,
                 worker_command=worker_command or self.worker_command,
                 n_workers=n_workers or self.n_workers,
                 image=image or self.image,
             )
+            spec["cluster"] = self.name
         data = {
             "apiVersion": "kubernetes.dask.org/v1",
             "kind": "DaskWorkerGroup",
@@ -706,7 +719,6 @@ def make_cluster_spec(
         "metadata": {"name": name},
         "spec": {
             "worker": make_worker_spec(
-                cluster_name=name,
                 env=env,
                 resources=resources,
                 worker_command=worker_command,
@@ -725,7 +737,6 @@ def make_cluster_spec(
 
 
 def make_worker_spec(
-    cluster_name,
     image="ghcr.io/dask/dask:latest",
     n_workers=3,
     resources=None,
@@ -744,7 +755,6 @@ def make_worker_spec(
     args = worker_command + ["--name", "$(DASK_WORKER_NAME)"]
 
     return {
-        "cluster": cluster_name,
         "replicas": n_workers,
         "spec": {
             "containers": [
@@ -845,5 +855,4 @@ def reap_clusters():
                     else:
                         cluster.close(timeout=10)
 
-    loop = asyncio.get_event_loop()
-    loop.run_until_complete(_reap_clusters())
+    asyncio.run(_reap_clusters())
